# Import verilog and setup libraries
set_host_options -max_cores 8 -num_processes 8

# Set paths !!! Please edit for your system !!!
set sc9mcpp240z_base_path /home/dwn1c21/SoC-Labs/phys_ip/arm/tsmc/cln28ht/sc12mcpp140z_base_svt_c35/r2p0
set cln28ht_tech_path /home/dwn1c21/SoC-Labs/phys_ip/arm/tsmc/cln28ht/arm_tech/r1p0

set TLU_dir /home/dwn1c21/SoC-Labs/phys_ip/arm/tsmc/cln28ht/arm_tech/r1p0/synopsys_tluplus/1p8m_5x2z_utalrdl

set TLU_cbest $TLU_dir/cbest.tluplus
set TLU_cbest_T $TLU_dir/cbest_T.tluplus
set TLU_cworst_T $TLU_dir/cworst_T.tluplus
set TLU_cworst $TLU_dir/cworst.tluplus
set TLU_rcbest_T $TLU_dir/rcbest_T.tluplus
set TLU_rcbest $TLU_dir/rcbest.tluplus
set TLU_rcworst_T $TLU_dir/rcworst_T.tluplus
set TLU_rcworst $TLU_dir/rcworst.tluplus
set TLU_typical $TLU_dir/typical.tluplus
set TLU_map $TLU_dir/tluplus.map

#Create the design library 
create_lib nanosoc_chip_pads.dlib \
    -technology $cln28ht_tech_path/milkyway/1p8m_5x2z_utalrdl/sc12mcpp140z_tech.tf \
    -ref_libs {../libs/cln28ht/ ../libs/cln28ht_pmk/ ../libs/cln28ht_ret/ ../libs/sram_16k/ ../libs/sram_32k/ ../libs/sram_64k/ ../libs/rom_via/ ../libs/io_lib/ ../libs/pad_lib/ ../libs/bump_lib/}

source $env(SOCLABS_PROJECT_DIR)/imp/ASIC/nanosoc/flist/dc_flist.tcl
analyze -format verilog $env(SOCLABS_PROJECT_DIR)/nanosoc_tech/ASIC/nanosoc_chip_pads/tsmc28hpcp/nanosoc_chip_pads_38pin.v

elaborate nanosoc_chip_pads
set_top_module nanosoc_chip_pads

redirect -tee -file ../logs/lib_cell_summary.log {report_lib -cell_summary cln28ht}
redirect -tee -file ../logs/lib_cell_pmk_summary.log {report_lib -cell_summary cln28ht_pmk}
redirect -tee -file ../logs/lib_cell_ret_summary.log {report_lib -cell_summary cln28ht_ret}
redirect -tee -file ../logs/lib_cell_bump_summary.log {report_lib -cell_summary bump_lib}

remove_modes -all
remove_corners -all
remove_scenarios -all

read_parasitic_tech -name cbest -tlup $TLU_cbest -layermap $TLU_map -sanity_check advanced
read_parasitic_tech -name cbest_T -tlup $TLU_cbest_T -layermap $TLU_map -sanity_check advanced
read_parasitic_tech -name cworst_T -tlup $TLU_cworst_T -layermap $TLU_map -sanity_check advanced
read_parasitic_tech -name cworst -tlup $TLU_cworst -layermap $TLU_map -sanity_check advanced
read_parasitic_tech -name rcbest_T -tlup $TLU_rcbest_T -layermap $TLU_map -sanity_check advanced
read_parasitic_tech -name rcbest -tlup $TLU_rcbest -layermap $TLU_map -sanity_check advanced
read_parasitic_tech -name rcworst_T -tlup $TLU_rcworst_T -layermap $TLU_map -sanity_check advanced
read_parasitic_tech -name rcworst -tlup $TLU_rcworst -layermap $TLU_map -sanity_check advanced
read_parasitic_tech -name typical -tlup $TLU_typical -layermap $TLU_map -sanity_check advanced

set_technology -node 28

## Setup scenarios as below
create_mode hold_mode
create_corner hold_corner
create_scenario -name hold_scenario -mode hold_mode -corner hold_corner
set_scenario_status hold_scenario -none -setup false -hold true -leakage_power true -dynamic_power false -max_transition true -max_capacitance false -min_capacitance true -active true

set_app_options -name time.convert_constraint_from_bc_wc -value bc_only
read_sdc ../../../constraints.sdc


create_mode setup_mode
create_corner setup_corner
create_scenario -name setup_scenario -mode setup_mode -corner setup_corner
set_scenario_status setup_scenario -none -setup true -hold false -leakage_power true -dynamic_power true -max_transition true -max_capacitance true -min_capacitance false -active true

set_app_options -name time.convert_constraint_from_bc_wc -value wc_only
read_sdc ../../../constraints.sdc

set_app_options -name time.convert_constraint_from_bc_wc -value none

## hold - FFGNP V=+10% T=-40 and 125, parasitics cworst cbest rcworst rcbest
#         SSSGNP V=-10%, T=-40 and 125, parasitics cworst and rcworst
current_corner hold_corner
set_parasitic_parameters -early_spec cbest -early_temperature -40 -late_spec cworst -late_temperature 125 -library nanosoc_chip_pads.dlib
set_operating_conditions -max_library cln28ht -max ssg_cworstt_max_0p81v_125c -min_library cln28ht -min ffg_cbestt_min_0p99v_m40c
set_temperature 125 -min -40 -corners hold_corner
set_voltage 0.81 -min 0.99 -corners hold_corner

## setup SSGNP V=-10%, T=-40 parasitics cworst_t rcworst_t
#        TT V=-10%, T=85C parasitics cworst_t rcworst_t
current_corner setup_corner
set_parasitic_parameters -early_spec cworst_T -early_temperature -40 -late_spec rcworst_T -late_temperature 125 -library nanosoc_chip_pads.dlib
set_operating_conditions -max_library cln28ht -max ssg_cworstt_max_0p81v_125c -min_library cln28ht -min tt_ctypical_max_0p90v_25c
set_temperature 85 -min -40 -corners setup_corner
set_voltage 0.81 -corners setup_corner


## max transition - SSGNP V=-10% T=-40 P=cworst_t rcworst_t

## typical power - TT V=V T=85C P=ctypical

# Max IR drop - FFG V=V T=125 P=cworst

# Signal EM - FFG V=V T=125 P=rcworst_c cworst_T

redirect -file ../reports/design_setup.report_scenarios.rpt {report_scenarios} 

save_block nanosoc_cip_pads
save_lib nanosoc_chip_pads.dlib

initialize_floorplan -control_type die -use_site_row -side_length {1111.1111 1611.11111} -core_offset {180}
source ../floorplan/fp.tcl

remove_io_guides -all 

create_io_ring -name main_io -pad_cell_list {uPAD_CLK_I uPAD_NRST_I uPAD_P0_00 uPAD_P0_01 uPAD_P0_02 uPAD_P0_03 uPAD_P0_04 uPAD_P0_05 uPAD_P0_06 uPAD_P0_07 uPAD_P1_00 uPAD_P1_01 uPAD_P1_02 uPAD_P1_03 uPAD_P1_04 uPAD_P1_05 uPAD_P1_06 uPAD_P1_07 uPAD_SE_I uPAD_SWDCK_I uPAD_SWDIO_IO uPAD_TEST_I uPAD_VDDACC_0 uPAD_VDDACC_1 uPAD_VDDACC_2 uPAD_VDDIO_0 uPAD_VDDIO_2 uPAD_VDDIO_3 uPAD_VDD_0 uPAD_VDD_1 uPAD_VDD_2 uPAD_VDD_3 uPAD_VSSIO_0 uPAD_VSSIO_1 uPAD_VSS_0 uPAD_VSS_1 uPAD_VSS_2 uPAD_VSS_3}
create_io_corner_cell {main_io.left main_io.top} -reference_cell PCORNER_G
create_io_corner_cell {main_io.bottom main_io.left} -reference_cell PCORNER_G
create_io_corner_cell {main_io.top main_io.right} -reference_cell PCORNER_G
create_io_corner_cell {main_io.right main_io.bottom} -reference_cell PCORNER_G

place_io
create_io_filler_cells -io_guides [get_io_guides {main_io.top main_io.right main_io.bottom main_io.left}] -reference_cells PFILLER5_G -prefix io_filler
create_io_filler_cells -io_guides [get_io_guides {main_io.top main_io.right main_io.bottom main_io.left}] -reference_cells PFILLER0005_G -prefix io_filler


# Power Plan
load_upf ../scripts/nanosoc_chip_pads.upf

create_voltage_area -power_domains ACCEL 
# create_voltage_area -power_domains PD_DBG
# create_voltage_area -power_domains PD_SYS
 
create_voltage_area_shape -voltage_area ACCEL \
				-region {{{180.500 180.000} {925.150 1000.000}}} \
				-guard_band {2 2}

#create_voltage_area_shape -voltage_area PD_DBG \
#				-region {{{140.000 673.000} {464.150 970.400}}} \
#				-guard_band {2 2}
#create_voltage_area_shape -voltage_area PD_SYS \
#				-region {{{594.440 523.900} {1012.365 970.400}}} \
#				-guard_band {2 2}

create_pg_region {pg_accel} -voltage_area {ACCEL}
# create_pg_region {pg_dbg} -voltage_area {PD_DBG}
# create_pg_region {pg_sys} -voltage_area {PD_SYS}


source ../scripts/power_plan.tcl

save_block 
save_lib nanosoc_chip_pads.dlib

set topMetalLayer 8;
set RDLMetal AP;
set RDLVia RV;
remove_antenna_rules

define_antenna_layer_rule \
  -mode 4 \
  -layer "$RDLMetal" \
  -ratio 2000 \
  -diode_ratio {0.000025 0 8000 30000}

define_antenna_rule \
  -mode 1 \
  -diode_mode 4 \
  -metal_ratio 0 \
  -cut_ratio 20

define_antenna_layer_rule  \
            -mode 1 \
            -layer "M$topMetalLayer" \
            -ratio 5000 \
            -diode_ratio {0.000025 0 8000 50000}

define_antenna_layer_rule  \
            -mode 1 \
            -layer "$RDLVia" \
            -ratio 200 \
            -diode_ratio {0.000025 0 83 400}

for {set i 1} {$i < $topMetalLayer} {incr i} {
  define_antenna_layer_rule  \
    -mode 1 \
    -layer "VIA$i" \
    -ratio 20 \
    -diode_ratio {0.000025 0 210 900}
}

define_antenna_rule  \
  -mode 2 \
  -diode_mode 4 \
  -metal_ratio 0 \
  -cut_ratio 0

for {set i 1} {$i < $topMetalLayer} {incr i} {
  define_antenna_layer_rule  \
    -mode 2 \
    -layer "M$i" \
    -ratio 5000 \
    -diode_ratio {0.000025 0 456 43000}
}

define_antenna_layer_rule  \
    -mode 2 \
    -layer "M$topMetalLayer" \
    -ratio 5000 \
    -diode_ratio {0.000025 0 8000 50000}

for {set i 1} {$i < $topMetalLayer} {incr i} {
  define_antenna_layer_rule  \
    -mode 2 \
    -layer "VIA$i" \
    -ratio 900 \
    -diode_ratio {0.000025 0 210 900}
}

##### Routing Option Related to Antenna Fixing #####
set_parameter -name doAntennaConx -value 4 -module droute

redirect -tee -file ../reports/antenna_rules.rpt {report_antenna_rules}

set_voltage -min 0.99 -corners hold_corner -object_list [get_supply_nets {VDD}] 0.81
set_voltage -min 0.99 -corners hold_corner -object_list [get_supply_nets {VDDACC}] 0.81
set_voltage -min 1.98 -corners hold_corner -object_list [get_supply_nets {AVDDHV}] 1.62
set_voltage -min 0.99 -corners hold_corner -object_list [get_supply_nets {AVDD}] 0.81
set_voltage -min 0.0 -corners hold_corner -object_list [get_supply_nets {VSS}] 0.0
set_voltage -min 0.0 -corners hold_corner -object_list [get_supply_nets {AGND}] 0.0

set_voltage -corners setup_corner -object_list [get_supply_nets {VDD}] 0.81
set_voltage -corners setup_corner -object_list [get_supply_nets {VDDACC}] 0.81
set_voltage -corners setup_corner -object_list [get_supply_nets {AVDDHV}] 1.62
set_voltage -corners setup_corner -object_list [get_supply_nets {AVDD}] 0.81
set_voltage -corners setup_corner -object_list [get_supply_nets {VSS}] 0.0
set_voltage -corners setup_corner -object_list [get_supply_nets {AGND}] 0.0


redirect -tee -file ./precompile_checks.log {compile_fusion -check_only}

explore_logic_hierarchy -create_module_boundary -nested -cell [get_cells -design [current_block] {u_nanosoc_chip u_nanosoc_chip_cfg}]
explore_logic_hierarchy -place -rectangular


save_block 
save_lib nanosoc_chip_pads.dlib
