#########################################
# File : Design Import Logic 
# Date : 22nd May 2022 
# Author : Srimanth Tenneti 
# Description : MMMC + Design Import 
######################################### 

### Settting PG Nets 
set_db init_power_nets {VDD VDDIO VDDACC} 
set_db init_ground_nets {VSS VSSIO} 

### Processing MMMC 
read_mmmc nanosoc.mmmc 

# Set library paths 
# !! EDIT THIS TO YOUR PATHS IN YOUR ENVIRONMENT
set TECH_LEF $::env(PHYS_IP)/arm/tsmc/cln65lp/arm_tech/r2p0/lef/1p9m_6x2z/sc9_tech.lef
set BASE_LEF $::env(PHYS_IP)/arm/tsmc/cln65lp/sc9_base_rvt/r0p0/lef/sc9_cln65lp_base_rvt.lef
set IO_PAD_LEF /home/dwn1c21/SoC-Labs/phys_ip/tsmc/cln65lp/Backend/lef/tpbn65v_9lm.lef
set IO_PAD_DRIVER_LEF /home/dwn1c21/SoC-Labs/phys_ip/tsmc/cln65lp/Backend/lef/tpdn65lpnv2od3_9lm.lef


# !! THESE SHOULD BE CORRECT FOR ANY ENVIRONMENT AS THEY ARE GENERATED BY MAKEFILE
set RF_16K_LEF $::env(SOCLABS_PROJECT_DIR)/memories/rf_16k/rf_16k.lef
set RF_08K_LEF $::env(SOCLABS_PROJECT_DIR)/memories/rf_08k/rf_08k.lef
set ROM_LEF $::env(SOCLABS_PROJECT_DIR)/memories/bootrom/rom_via.lef

### Reading LEFs 
read_physical -lef [list ${TECH_LEF} ${BASE_LEF} ${IO_PAD_LEF} ${IO_PAD_DRIVER_LEF} ${RF_16K_LEF} ${RF_08K_LEF} ${ROM_LEF}]

### Reading Netlist 
read_netlist $::env(SOCLABS_PROJECT_DIR)/imp/ASIC/nanosoc/netlist/nanosoc_chip_pads_28pin.v

### Read DEF scan chain
#read_def $::env(SOCLABS_PROJECT_DIR)/imp/ASIC/nanosoc/netlist/nanosoc_chip_pads_28pin.def

### Initializing the Design 
init_design

### Adjusting the GUI 
gui_fit 

ungroup u_nanosoc_chip_u_system

create_floorplan -core_margins_by die -flip s -site sc9_cln65lp -die_size 1000.0 1000.0 135.0 135.0 135.0 135.0

read_power_intent -cpf ../cpf/nanosoc_imp.cpf


